@@ -20,7 +20,7 @@
  *
  *
  * nessus-fetch is a simple utility to retrieve Nessus plugins from nessus.org
- * $Id: nessus-fetch.c,v 1.1.2.22 2006/09/18 08:54:50 renaud Exp $
+ * $Id: nessus-fetch.c,v 1.6 2004/12/11 01:13:17 renaud Exp $
  */
 #include <includes.h>
 
@@ -32,20 +32,13 @@
 #define WWW_NESSUS_ORG "www.nessus.org"
 #define PLUGINS_NESSUS_ORG "plugins.nessus.org" 
 
-#define SOCKET_TIMEOUT 90
-
 #define ERROR_PREFIX "@ERROR@:"
 #define SUCCESS_MSG  "@SUCCESS@"
 #define CONFIG_FILE "nessus-fetch.rc"
 
-#define SEGSIZE 1024
-
 #ifndef INADDR_NONE
 #define INADDR_NONE 0xffffffff
 #endif
-
-
-
 static int unblock_socket(int soc)
 {
   int   flags =  fcntl(soc, F_GETFL, 0);
@@ -78,58 +71,6 @@ static int block_socket(int soc)
   return 0;
 }
 
-int http_recv_headers(int soc, char ** result, int * len)
-{
- char tmp[2048];
- int sz = 4096;
- int n;
- char * buf;
- int lines = 0;
- int num = 0;
- 
- *result = NULL;
- *len = 0;
- 
- buf = emalloc(sz);
- tmp[ sizeof(tmp) - 1 ] = '\0';
-
-  for(;;)
-  {
-   n = recv_line(soc, tmp, sizeof(tmp) - 1);
-   lines ++;
-   if( n <= 0 )break;
-   
-   if(!strcmp(tmp, "\r\n")||
-      !strcmp(tmp, "\n"))break;
-   else 
-   {
-     num  += n;
-     if(num < sz)
-      strcat(buf, tmp);
-     else
-     {
-      if(sz > 1024 * 1024)
-       break;
-      else
-       sz = (sz * 2) > ( num + 1 ) ? (sz * 2) : (num + 1);
-	
-      buf = erealloc(buf, sz);
-      strcat(buf, tmp);
-      if(lines > 100)break;
-     }
-  }
- }
- 
- if(num == 0)
- {
-  efree(&buf);
- }
- 
- *result = buf;
- *len = num;
- return 0;
-}
-
 
 
 /*-------------------------------------------------------------------------
@@ -293,10 +234,7 @@ struct preferences {
 	char * proxy_port;
 	char * proxy_username;
 	char * proxy_password;
-	char * user_agent;
 };
-
-int proxy_connect_method(char * hostname, int port, struct preferences * prefs, struct arglist * hostinfo);
 	
 
 static void save_preferences( struct preferences * prefs )
@@ -320,8 +258,6 @@ static void save_preferences( struct preferences * prefs )
 		prefs->proxy_username ? prefs->proxy_username:"",
 		prefs->proxy_password ? prefs->proxy_password : "");
 
- if ( prefs->user_agent != NULL )
-	fprintf(fp, "user_agent=%s\n", prefs->user_agent);
 
  fclose(fp);
  chmod(path, 0600);
@@ -371,9 +307,6 @@ static int load_preferences( struct preferences * prefs )
 
  else if ( strncmp(buf, "proxy_password=", strlen("proxy_password=") ) == 0 )
  	prefs->proxy_password = shift_pref(buf, "proxy_password=");
-
- else if ( strncmp(buf, "user_agent=", strlen("user_agent=") ) == 0 )
- 	prefs->user_agent = shift_pref(buf, "user_agent=");
  }
 
  fclose(fp);
@@ -427,9 +360,7 @@ static int recv_chunked_encoding(int fd, char * headers, int hlen, char ** buf,
   n = 0;
   do {
   int e = 0;
-  int l;
-  l = total_len + 2 - n > SEGSIZE ? SEGSIZE : total_len + 2 - n;
-  e = read_stream_connection_min(fd, mybuf + sz + n, 1, l );
+  e = read_stream_connection_min(fd, mybuf + sz + n, total_len + 2 - n, total_len + 2 - n );
   if ( e <= 0 ) break;
   n += e;
   } while ( n != total_len + 2);
@@ -488,8 +419,8 @@ static char * http_recv(int fd, int * totlen, int * headerslen, int * error_code
    int e;
    int readsz;
 
-   readsz = (len - n)  > SEGSIZE ? SEGSIZE : (len - n);
-   e = read_stream_connection_min(fd, retbuf + headers_len + n, 1, readsz);
+   readsz = (len - n)  > 65535 ? 65535 : (len - n);
+   e = read_stream_connection_min(fd, retbuf + headers_len + n, readsz, readsz);
    if ( e <= 0 ) break;
    else n += e;
   }
@@ -511,8 +442,9 @@ static char * http_recv(int fd, int * totlen, int * headerslen, int * error_code
   }
   else
   {
+#define CHUNKSZ 16384
    int len = headers_len;
-   int bufsz = len + SEGSIZE * 5;
+   int bufsz = len + CHUNKSZ * 5;
    char * buf = emalloc( bufsz );
    int n;
    
@@ -520,11 +452,11 @@ static char * http_recv(int fd, int * totlen, int * headerslen, int * error_code
    for (n = 0;; )
    {
    int e;
-   e = read_stream_connection_min(fd, buf + headers_len + n, 1, SEGSIZE );
+   e = read_stream_connection(fd, buf + headers_len + n, CHUNKSZ);
    if ( e <= 0 ) break;
    else { len += e; n += e; }
 
-   if ( len + SEGSIZE >= bufsz )
+   if ( len + CHUNKSZ >= bufsz )
 	{
 	 if ( bufsz > MAX_SIZE ) break;
 	 bufsz *= 2;
@@ -548,7 +480,6 @@ char * mk_http_req(const char * hostname, char * path, char * httpuser, char * h
   struct preferences prefs;
   char proxy_auth[1024];
   char auth[1024];
-  char ua[512];
 
   load_preferences(&prefs);
 
@@ -572,18 +503,16 @@ char * mk_http_req(const char * hostname, char * path, char * httpuser, char * h
  }
  else auth[0] = '\0';
 
- snprintf(ua, sizeof(ua), "Nessus-Fetch/%s", nessuslib_version());
 
   sprintf(str, "GET %s HTTP/1.1\r\n\
 Connection: Close\r\n\
 Host: %s\r\n\
 Pragma: no-cache\r\n\
-User-Agent: %s\r\n\
-X-Nessus: %s\r\n\
+User-Agent: Nessus-Fetch/%s\r\n\
 %s%sAccept: image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, image/png, */*\r\n\
 Accept-Language: en\r\n\
 Accept-Charset: iso-8859-1,*,utf-8\r\n\r\n",
-                path, hostname, ( prefs.user_agent != NULL && prefs.user_agent[0] != '\0' ) ? prefs.user_agent : ua, nessuslib_version(), proxy_auth[0] ? proxy_auth:"", auth[0] ? auth:"");
+                path, hostname, nessuslib_version(), proxy_auth[0] ? proxy_auth:"", auth[0] ? auth:"");
 
   return str;
 }
@@ -625,72 +554,7 @@ static struct arglist * mkhostinfo(char * hostname)
 
 
 /*--------------------- Register a user -------------------------------------*/
-static void update_plugins(int argc, char ** argv)
-{
- char * ptr;
- char path[1024];
- char * my_argv[] = { "nessus-update-plugins", NULL };
- pid_t pid;
- int e;
-
- printf("Now fetching the newest plugin set from plugins.nessus.org...\n");
-
- ptr = find_in_path("nessus-update-plugins", 0);
- if ( ptr == NULL )
- {
-  strncpy(path, argv[0], sizeof(path) - strlen("nessus-update-plugins") );
-  path[sizeof(path) - strlen("nessus-update-plugins") ] = '\0';
-  if ( path[0] == '/' ) 
-	{
-	 ptr = strstr(path, "/bin/");
-	 if ( ptr != NULL )
-         {
-	  ptr[0] = '\0';
-	  strncat(path, "/sbin/nessus-update-plugins", sizeof(path) - strlen(path) - 1);
-	  path[sizeof(path) - 1] = '\0';
-	  ptr = &(path[0]);
-         }
-	}
-  else ptr = NULL;
- }
- else 
-  {
-  snprintf(path, sizeof(path), "%s/nessus-update-plugins", ptr);
-  ptr = &(path[0]);
-  }
-
- if ( ptr == NULL )
- {
-  fprintf(stderr, "nessus-update-plugins could not be found in your $PATH\n");
-  exit(1);
- }
- pid = fork();
- if ( pid == 0 )
- {
-  if ( execv(ptr, my_argv) < 0 ) 
-   fprintf(stderr, "Could not execute %s - %s\n", ptr, strerror(errno));
-  exit(0);
- }
- else if ( pid < 0 ) {
-	fprintf(stderr, "fork() failed (%s)\n", strerror(errno));
-	exit(1);
-	}
- 
- do {
-	errno = 0;
-	e = waitpid(pid, NULL, 0);
-    } while ( e < 0 && errno == EINTR );
-
- 
- printf("Your Nessus installation is now up-to-date.\nMake sure to call regularly use the command 'nessus-update-plugins' to stay up-to-date\n");
- printf("To automate the update process, please visit <http://www.nessus.org/documentation/index.php?doc=cron>\n");
- printf("\n");
- 
- exit(0);
-}
-
-
-static int do_register( char * serial, int argc, char ** argv )
+static int do_register( char * serial )
 {
  char * req, * result;
  char str[1024];
@@ -709,17 +573,14 @@ static int do_register( char * serial, int argc, char ** argv )
   snprintf(str, sizeof(str), "/register.php?serial=%s", serial);
 
  req = mk_http_req(plug_get_hostname(hostinfo), str, NULL, NULL);
- if ( prefs.proxy && prefs.proxy_port )
-  soc = proxy_connect_method(PLUGINS_NESSUS_ORG, HTTPS_PORT, &prefs, hostinfo);
- else
-  soc = open_stream_connection(hostinfo, HTTPS_PORT, NESSUS_ENCAPS_TLSv1,  SOCKET_TIMEOUT);
 
+ soc = open_stream_connection(hostinfo, ( prefs.proxy && prefs.proxy_port ) ? atoi(prefs.proxy_port) : HTTPS_PORT, NESSUS_ENCAPS_TLSv1,  60);
  if ( soc < 0 ) 
  {
   fprintf(stderr, "could not connect to %s - %s\n", plug_get_hostname(hostinfo), strerror(errno));
   exit(1);
  } 
- stream_set_buffer(soc, 0);
+ stream_set_buffer(soc, 65535);
 
  write_stream_connection(soc, req, strlen(req));
    
@@ -753,7 +614,6 @@ static int do_register( char * serial, int argc, char ** argv )
   prefs.password = password;
   save_preferences(&prefs);
   printf("Your activation code has been registered properly - thank you.\n");
-  update_plugins(argc, argv);
   exit(0);
  }
  else if ( strncmp(result, "EEXIST", strlen("EEXIST")) == 0 )
@@ -773,7 +633,6 @@ error:
 int proxy_connect_method(char * hostname, int port, struct preferences * prefs, struct arglist * hostinfo)
 {
  char buf[1024];
- char ua[512];
  const char * base64;
  char proxy_auth[256];
  static SSL_CTX        *ssl_ctx = NULL;
@@ -782,8 +641,6 @@ int proxy_connect_method(char * hostname, int port, struct preferences * prefs,
  int n;
  int fd, soc;
 
- snprintf(ua, sizeof(ua), "Nessus-Fetch/%s", nessuslib_version());
-
 
 	if ( prefs->proxy_username != NULL && prefs->proxy_password != NULL )
 	{
@@ -793,9 +650,9 @@ int proxy_connect_method(char * hostname, int port, struct preferences * prefs,
 	}
 	else proxy_auth[0] = '\0';
 
-  	soc = open_stream_connection ( hostinfo, atoi(prefs->proxy_port), NESSUS_ENCAPS_IP, SOCKET_TIMEOUT );
+  	soc = open_stream_connection ( hostinfo, atoi(prefs->proxy_port), NESSUS_ENCAPS_IP, 60 );
        fd = nessus_get_socket_from_connection(soc); 
-	snprintf(buf, sizeof(buf), "CONNECT %s:%d HTTP/1.0\r\nUser-Agent: %s\r\n%s\r\n", hostname, port, ( prefs->user_agent != NULL && prefs->user_agent[0] != '\0' ) ? prefs->user_agent : ua, proxy_auth);
+	snprintf(buf, sizeof(buf), "CONNECT %s:%d HTTP/1.0\r\nUser-Agent: Mozilla/4.73 (Win95;I)\r\n%s\r\n", hostname, port, proxy_auth);
 	write_stream_connection ( soc, buf, strlen(buf) );
 	n = read_stream_connection(soc, buf, sizeof(buf) - 1);
 	if ( n < 0 || strstr(buf, " 200 " ) == NULL || strstr(buf, "\r\n\r\n") == NULL )
@@ -837,7 +694,7 @@ int proxy_connect_method(char * hostname, int port, struct preferences * prefs,
 	SSL_set_connect_state(ssl);
   
         unblock_socket(fd);
-      if (ssl_connect_timeout(ssl, SOCKET_TIMEOUT) <= 0)
+      if (ssl_connect_timeout(ssl, 15) <= 0)
         {
           fprintf(stderr, "SSL_connect failed\n");
           exit (1);
@@ -889,13 +746,13 @@ void fetch_file(int encaps, int port, char * hostname, char * path, char * filen
 	 proxy = 0;
 	}
   else 
-	soc = open_stream_connection ( hostinfo, atoi(prefs.proxy_port), NESSUS_ENCAPS_IP, SOCKET_TIMEOUT );
+	soc = open_stream_connection ( hostinfo, atoi(prefs.proxy_port), NESSUS_ENCAPS_IP, 60 );
  }
  else {
  if ( encaps > 0 )
-  soc = open_stream_connection ( hostinfo, ( prefs.proxy && prefs.proxy_port ) ? atoi(prefs.proxy_port) : port, encaps, SOCKET_TIMEOUT );
+  soc = open_stream_connection ( hostinfo, ( prefs.proxy && prefs.proxy_port ) ? atoi(prefs.proxy_port) : port, encaps, 60 );
  else
-  soc = open_stream_connection ( hostinfo, ( prefs.proxy && prefs.proxy_port ) ? atoi(prefs.proxy_port) : port, NESSUS_ENCAPS_TLSv1, SOCKET_TIMEOUT );
+  soc = open_stream_connection ( hostinfo, ( prefs.proxy && prefs.proxy_port ) ? atoi(prefs.proxy_port) : port, NESSUS_ENCAPS_TLSv1, 60 );
  }
 
 
@@ -965,8 +822,6 @@ void check_subscription()
   {
   direct_feed = 1;
   snprintf(path, sizeof(path), "/get.php?u=%s&p=%s&f=check", prefs.login, prefs.password);
-
-
   fetch_file(NESSUS_ENCAPS_TLSv1, HTTPS_PORT, PLUGINS_NESSUS_ORG, path, NULL, NULL, NULL, &result);
   if ( result == NULL )
 	{
@@ -975,7 +830,7 @@ void check_subscription()
 	}
   if (strstr(result, SUCCESS_MSG) != NULL )
   {
-   fprintf(stderr, "nessus-fetch is properly configured to receive a plugin feed\n");
+   fprintf(stderr, "nessus-fetch is properly configured to receive a direct plugin feed\n");
    exit(0);
   }
   else if ( strstr(result, ERROR_PREFIX ) != NULL )
@@ -986,7 +841,7 @@ void check_subscription()
   }
  }
  else {
-   fprintf(stderr, "nessus-fetch is not configured to receive a plugin feed\n");
+   fprintf(stderr, "nessus-fetch is not configured to receive a direct plugin feed\n");
    exit(1);
    }
  
@@ -1055,7 +910,7 @@ int main(int argc, char ** argv)
    exit(1);
   }
   serial = argv[2];
-  do_register(serial, argc, argv);  
+  do_register(serial);  
   exit(1);
  }
  else if ( argc == 2 && strcmp(argv[1], "--plugins") == 0 )
