@@ -37,6 +37,7 @@
  */
 
 #include <includes.h>
+#include "nessus_i18n.h"
 #include "backend.h"
 #include "nsr_output.h"
 #include "nbe_output.h"
@@ -75,24 +76,19 @@ backend_init(fname)
  char * tmpfile;
  int i = 0;
  char * tmpdir;
- static int bzeroed = 0;
-
- if ( bzeroed == 0 )
- {
-   bzero(backends, sizeof(backends));
-   bzeroed ++;
- }
  
  while((backends[i].fname) && (i<MAX_TMPFILES))i++;
  if(backends[i].fname)
   {
-   show_error("No free tempfile !\n");
+   show_error(_("No free tempfile!"));
    return -1;
   }
  if(!fname)
  {
  tmpdir = getenv("TMPDIR");
  if(!tmpdir)tmpdir = getenv("TEMPDIR");
+ if(!tmpdir)tmpdir = getenv("TMP");
+ if(!tmpdir)tmpdir = getenv("TEMP");
  if(!tmpdir)tmpdir = "/tmp";
  
  tmpfile = emalloc(strlen(tmpdir) + strlen("/nessus-XXXXXX") + 1);
@@ -108,7 +104,7 @@ backend_init(fname)
 #endif
  if(backends[i].fd < 0)
  {
-   show_error(strerror(errno));
+   show_error(_("Can't create file %s: %s"), tmpfile, strerror(errno));
    efree(&tmpfile);
    return -1;
  }
@@ -118,7 +114,7 @@ backend_init(fname)
  {
   if((backends[i].fd = open(fname,O_RDONLY)) < 0)
    {
-   show_error(strerror(errno));
+   show_error(_("Can't open file %s: %s"), fname, strerror(errno));
    return -1;
    }
   tmpfile = estrdup(fname);
@@ -157,7 +153,7 @@ backend_type(be)
 
 
 /*
- * backend_inset_scaninfo_timestamp
+ * backend_insert_scaninfo_timestamp
  */
 int
 backend_insert_timestamps(be, host, type, time)
@@ -258,18 +254,18 @@ backend_insert_report_data(be, subnet, host, port, script_id, severity, data)
 int _backend_cmpcb(void *unused, harglst *not_used, hargkey_t *lKey,
 	hargtype_t lType, hargkey_t *rKey, hargtype_t rType) 
 {
-	unsigned long rin,lin;
+	in_addr_t rin,lin;
 	unsigned long rip,lip;
-	rin = (unsigned long)inet_addr(rKey);
-	lin = (unsigned long)inet_addr(lKey);
-	if(rin == 0xffffffff) {
-		if(lin == 0xffffffff) {
+	rin = inet_addr(rKey);
+	lin = inet_addr(lKey);
+	if(rin == -1) {
+		if(lin == -1) {
 			return strcmp(rKey,lKey);
 		} else {
 			return 1;
 		}
 	} else {
-		if(lin == 0xffffffff) {
+		if(lin == -1) {
 			return -1;
 		} else {
 			rip = ntohl(rin);
@@ -289,7 +285,7 @@ backend_convert(be)
  int be;
 {
  harglst * hhosts;
- FILE * fd;  
+ FILE * fd = fopen(backends[be].fname, "r");
  char buf[65535];
  char * current_hostname = NULL;
  struct arglist* current_host = NULL;
@@ -298,11 +294,6 @@ backend_convert(be)
  int line = 0;
  unsigned x;
 
- if ( backends[be].fname == NULL )
-	return NULL; 
-
- fd = fopen(backends[be].fname, "r");
-
  if(!fd)
   {
    perror("fopen ");
@@ -427,13 +418,7 @@ backend_convert(be)
   	buffer = estrdup("INFO");
   else if(!strcmp(t, "Security Hole"))
   	buffer = estrdup("REPORT");
-  else buffer = NULL;
  
-  if ( buffer == NULL )
-	{
-	 fprintf(stderr, "Error - line %d is malformed\n", line);
-	 continue;
-	}
   content = arg_get_value(port, buffer);
   
   if(!content)
@@ -485,7 +470,10 @@ backend_close(be)
 #ifdef HAVE_MMAP
  if(backends[be].mmap)
  {
-  int len = backends[be].mmap_size;
+  struct stat  buf;
+  int len;
+  fstat(backends[be].fd, &buf);
+  len = (int)buf.st_size;
   munmap(backends[be].mmap, len);
   backends[be].mmap = NULL;
   efree(&backends[be].lines);
@@ -609,7 +597,7 @@ backend_import_report(fname)
   {
    return nbe_to_backend(fname); /* for now, we only pipe nbe files via stdin */
   }
-  show_error("Unknown report type - please set an extension to the filename");
+  show_error(_("Unknown report type - please set an extension to the filename"));
   return -1;
  }
  
@@ -623,6 +611,6 @@ backend_import_report(fname)
   return nbe_to_backend(fname);
  }
  
- show_error("This file format can not be read back by the Nessus client");
+ show_error(_("This file format can not be read back by the Nessus client"));
  return -1;
 }
