@@ -65,20 +65,20 @@
 
  -------------------------------------------------------------------*/	
 #include <includes.h>
+#include "nessus_i18n.h"
 #include "gdchart0.94b/gdc.h"
 #include "gdchart0.94b/gdchart.h"
 #include "gdchart0.94b/gdcpie.h"
 #include "report.h"
 #include "report_utils.h"
 #include "error_dialog.h"
-#include "globals.h"
 #include "nsr_output.h"
 
 
 static void insert_img(FILE *, char*);
 
 
-extern int out_graph(short, short, FILE *, GDC_CHART_T, int, char **, int, ...);
+extern int out_graph(short, short, FILE *, GDC_CHART_T, int, char **, int, float *);
 
 
 
@@ -566,7 +566,8 @@ print_data_with_links(file, str, plugin_id)
   str = extract_xref(file, str, "http://cgi.nessus.org/bid.php3?bid=");
   }
   else fputc(str[0], file);
-  if ( str != NULL ) str++;
+  if(str != NULL)
+    str++;
  }
  
  fprintf(file, "Nessus ID : <a href=\"http://cgi.nessus.org/nessus_id.php3?id=%s\">%s</a>", plugin_id, plugin_id);
@@ -895,7 +896,7 @@ create_host_report(struct arglist * host)
    /*
     * Make a pie
     */
-    if(total > 1)
+    if(total)
     {
     pie = fopen("pie_risks.gif", "wb");
     GDCPIE_other_threshold = -1;
@@ -909,7 +910,7 @@ create_host_report(struct arglist * host)
     GDCPIE_label_size = GDC_SMALL;
     GDCPIE_title_size = GDC_MEDBOLD;
     GDCPIE_3d_angle  = 45;
-    if ( total > 1 ) GDCPIE_explode   = expl;
+    GDCPIE_explode   = expl;
     GDCPIE_Color = clr;
     GDCPIE_BGColor = 0xFFFFFFL;
     GDC_generate_gif = TRUE;
@@ -1044,7 +1045,7 @@ static int html_make_index(hosts)
    
    expl[num_risks-1] = 20;
    
-   if(num_risks > 1)
+   if(num_risks)
    {			
     pie = fopen("pie_risks.gif", "wb");
     GDCPIE_title = "Security Risks";
@@ -1195,7 +1196,7 @@ static int html_make_index(hosts)
     names[1] = "Others";
 
 
-    if (values[1] != 0 && total > 1 )
+    if (values[1] != 0 )
     {
     pie = fopen("pie_most.gif", "wb");
     GDCPIE_other_threshold = -1;
@@ -1210,9 +1211,9 @@ static int html_make_index(hosts)
     GDCPIE_EdgeColor = 0x000000L;
     GDCPIE_missing = NULL;
     GDCPIE_percent_labels = GDCPIE_PCT_RIGHT;
-    pie_gif(480, 360, pie, GDC_3DPIE, 2,names, values);
-    fclose(pie);
-    insert_img(f, "pie_most.gif");
+   pie_gif(480, 360, pie, GDC_3DPIE, 2,names, values);
+   fclose(pie);
+   insert_img(f, "pie_most.gif");
      }
     }
     }
@@ -1281,13 +1282,15 @@ int arglist_to_html_graph(hosts, directory)
  
  if(mkdir(directory, 0750)<0)
  {
-  show_error(strerror(errno));
+  show_error(_("Directory %s couldn't be created: %s."),
+      directory, strerror(errno));
   return -1;
  }
  
  if(chdir(directory)<0)
  {
-  show_error(strerror(errno));
+  show_error(_("Can't change to directory %s: %s."),
+      directory, strerror(errno));
   return -1;
  }
  
@@ -1297,7 +1300,7 @@ int arglist_to_html_graph(hosts, directory)
  arglist_to_file(hosts, "report.nsr"); 
  if(html_make_index(hosts)<0)
  {
-  show_error(strerror(errno));
+  show_error(_("Can't write index: %s"), strerror(errno));
   return -1;
  }
 
