@@ -41,7 +41,6 @@
 #include "report.h"
 #include "report_utils.h"
 #include "error_dialog.h"
-#include "globals.h"
 
 
 static char * convert_cr_to_html(char *);
@@ -133,7 +132,8 @@ print_data_with_links(file, str, plugin_id)
   str = extract_xref(file, str, "http://cgi.nessus.org/bid.php3?bid=");
   }
   else fputc(str[0], file);
-  if ( str != NULL ) str++;
+  if(str != NULL)
+    str++;
  }
  
  fprintf(file, "Nessus ID : <a href=\"http://cgi.nessus.org/nessus_id.php3?id=%s\">%s</a>", plugin_id, plugin_id);
