@@ -29,26 +29,30 @@
 
 #include <includes.h>
 
-#include "backend.h"
-#if USE_GTK 
+#ifdef USE_GTK 
 #include <gtk/gtk.h>
 
+#include "backend.h"
+#include "context.h"
+#include "preferences.h"
 #include "attack.h"
 #include "xstuff.h"
 #include "comm.h"
 #include "auth.h"
-#include "parser.h"             
+#include "parser.h"
 #include "report.h"
 #include "globals.h"
 #include "error_dialog.h"
 #include "xpm/computer.xpm"
 #include "monitor_dialog.h"
-#include "report_ng.h"
+#include "nessus_i18n.h"
+#include "prefs_dialog/prefs_context.h"
+#include "prefs_dialog/prefs_scope_tree.h"
 
 /*static char ** plugins_order_table = NULL;*/
 static harglst * plugins_order_table = NULL;
 
-static void monitor_input_callback(struct arglist *, int, int);
+static void monitor_input_callback(struct arglist *);
 static void monitor_add_host(struct arglist *, char *, int);
 static void monitor_stop_test(GtkWidget *, char *);
 static void monitor_list_update(struct arglist *, char *, int);
@@ -56,13 +60,6 @@ static int monitor_stop_whole_test_destroy(void*, void*, struct arglist *);
 static int monitor_stop_whole_test(GtkWidget * , struct arglist *);
 static void build_plugins_order_table(char *);
 
-struct gui_host {
-	GtkWidget * gui;
-	struct arglist * ctrls;
-	struct gui_host * next;
-};
-
-
 
 static int 
 is_server_present(soc)
@@ -74,7 +71,7 @@ is_server_present(soc)
 
 	if(fd < 0 || fd >= FD_SETSIZE)
 	{
-	 fprintf(stderr, "is_server_present: fd(%d) out of range\n", fd);
+	 fprintf(stderr, _("is_server_present: fd(%d) out of range\n"), fd);
 	 return 0;
 	}
 	FD_ZERO(&rd);
@@ -105,29 +102,23 @@ idle_socket(struct arglist * ctrls)
 {
   fd_set rd;
   struct timeval tv = {0,100};
-  int n, soc = -1;
-  if(GlobalSocket < 0)
+  int n, soc;
+  if(Context->socket < 0)
     {
-      fprintf(stderr, "idle_socket: GlobalSocket=%d\n", GlobalSocket);
+      fprintf(stderr, "idle_socket: Context->socket=%d\n", Context->socket);
       return FALSE;
     }
-
-  if ( stream_pending(GlobalSocket) > 0 )
-  {
-    monitor_input_callback(ctrls, soc /* ? Not used */, 0);
-    return TRUE;
-  }
-  soc = nessus_get_socket_from_connection(GlobalSocket);
+  soc = nessus_get_socket_from_connection(Context->socket);
   if((soc < 0) || (soc >= FD_SETSIZE))
   {
-   fprintf(stderr, "idle_server: soc(%d) out of range\n", soc);
+   fprintf(stderr, _("idle_server: soc(%d) out of range\n"), soc);
    return -1;
   }
   FD_ZERO(&rd);
   FD_SET(soc, &rd);
   n = select(soc+1, &rd, NULL, NULL, &tv);
   if(FD_ISSET(soc, &rd)&& (n > 0))
-    monitor_input_callback(ctrls, soc /* ? Not used */, 0);
+    monitor_input_callback(ctrls);
   return TRUE;
 }
 
@@ -138,44 +129,43 @@ idle_socket(struct arglist * ctrls)
  * show the attack status
  */
 void 
-monitor_dialog_setup(victim, restore)
+monitor_dialog_setup(victim)
      char * victim;
-     int restore;
 {
   struct arglist * ctrls = emalloc(sizeof(struct arglist));
+  GtkWindow* parent = arg_get_value(MainDialog, "CONTEXT");
   GtkWidget * scrolled_window; 
   GtkWidget * w, * box;
   char* window_title;
-  char* host_name;
+  const char* host_name;
   int tag;
   int backend = backend_init(NULL);
 
   /* Could not create a backend */
   if( backend < 0 )
-  {
-    gtk_widget_show(arg_get_value(MainDialog, "WINDOW"));
     return;
-  }
-  
 
   arg_add_value(ctrls, "MONITOR_BACKEND", ARG_INT, -1, (void*)backend);
-  
+  arg_add_value(ctrls, "PARENT", ARG_PTR, -1, parent);
+
   w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-#if GTK_VERSION > 10
   gtk_window_set_default_size(GTK_WINDOW(w), 640,480);
-#else
-  gtk_widget_set_usize(GTK_WIDGET(w), 640, 480);
-#endif
+
+  /* TODO make the window non-modal
+   * This can be done when context is kept for all called functions */
+  gtk_window_set_modal(GTK_WINDOW(w), TRUE);
+  gtk_window_set_transient_for(GTK_WINDOW(w), parent);
+  arg_set_value(MainDialog, "CONTEXT", -1, w);
 
   gtk_widget_realize(w);
   gtk_signal_connect(GTK_OBJECT(w), "delete_event",
 		     (GtkSignalFunc)monitor_stop_whole_test_destroy,ctrls);
 		     
-  host_name = arg_get_value(Prefs, "nessusd_host");
+  host_name = prefs_get_string(Context, "nessusd_host");
   if(host_name)window_title = emalloc(strlen(host_name) + 255);
   else window_title = emalloc(255);
-  sprintf(window_title, "Scanning network from %s",
-  	host_name?host_name:"some host");		     
+  sprintf(window_title, _("Scanning network from %s"),
+          host_name?host_name:_("some host"));
   gtk_window_set_title(GTK_WINDOW(w), window_title);
   efree(&window_title);
   gtk_container_border_width(GTK_CONTAINER(w), 10);
@@ -195,11 +185,7 @@ monitor_dialog_setup(victim, restore)
   gtk_box_pack_start(GTK_BOX(box), scrolled_window, TRUE, TRUE, 0);
   
   w = gtk_list_new();
-#if GTK_VERSION < 11
-  gtk_container_add(GTK_CONTAINER(scrolled_window), w);
-#else
   gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_window), w);
-#endif
   gtk_widget_show(w);
   gtk_widget_show (scrolled_window);
   arg_add_value(ctrls, "LIST", ARG_PTR, -1, w);
@@ -209,17 +195,20 @@ monitor_dialog_setup(victim, restore)
   tag = gtk_idle_add((GtkFunction)idle_socket, ctrls);
   
   arg_add_value(ctrls, "TAG", ARG_INT, sizeof(int), (void*)tag);
-  w = gtk_button_new_with_label("Stop the whole test");
+  w = gtk_button_new_with_label(_("Stop the whole test"));
   gtk_signal_connect(GTK_OBJECT(w), "clicked",
 		     (GtkSignalFunc)monitor_stop_whole_test,ctrls);
   gtk_box_pack_start(GTK_BOX(box), w, FALSE, TRUE, 0);
   gtk_widget_show(w);
-#if ENABLE_SAVE_TESTS
-  if(restore)
-   restore_attack(victim, Prefs);
-  else
-#endif
-   attack_host(victim, Prefs);
+  if(!attack_host(victim, Context))
+  {
+    gtk_widget_hide(arg_get_value(ctrls, "WINDOW"));
+    gtk_idle_remove(tag);
+    gtk_widget_destroy(arg_get_value(ctrls, "WINDOW"));
+    arg_set_value(MainDialog, "CONTEXT", -1, parent);
+    prefs_context_update(Context);
+    scopetreeview_connected_update(Context);
+  }
 }
 
 /*
@@ -279,7 +268,7 @@ monitor_list_update(ctrls,msg, short_status)
   item = GTK_OBJECT(dlist->data);
   list_hostname = gtk_object_get_data(item, "hostname");
   if(!list_hostname){
-  	fprintf(stderr, "Error ! Null hostname in the list\n");
+    fprintf(stderr, _("Error ! Null hostname in the list\n"));
   	/*exit(1);*/
 	return;
   	}
@@ -295,9 +284,9 @@ monitor_list_update(ctrls,msg, short_status)
     
    gmax = max;
    gcurrent = atoi(current);
-   f = (gfloat)(gcurrent/gmax);
-   if(f >= 1.0)f = 0.99;
-   else if(f <= 0)f = 0;
+   f = (gcurrent/gmax);
+   if(f>1)f=1;
+   if(f<0.0)f=0.0;
    gtk_progress_bar_update (GTK_PROGRESS_BAR(progress_bar), f);
 
    flag = 1;
@@ -330,17 +319,11 @@ monitor_remove_host(ctrls, host)
  item =  gtk_object_get_data(GTK_OBJECT(arg_get_value(ctrls, "LIST")),host);
  
  if(!item){
-#ifndef ENABLE_SAVE_KB
 	/*
 	 * If this happens, then it's very likely that the server
 	 * thinks the communication has been cut between the client
 	 * and itself. Which is not a good thing.
 	 */
- 	fprintf(stderr, "warning. Could not find entry for %s\n", host);
-	fprintf(stderr, "This may be a bug - please check the nessusd logfile\n");
-	fprintf(stderr, "and if you see something about a lost connection,\n");
-	fprintf(stderr, "or any odd message, please report it to deraison@cvs.nessus.org\n");
-#endif	
 	return;
 	}
  
@@ -426,11 +409,11 @@ monitor_add_host(ctrls,hostname,port)
  gtk_widget_show(box);
  gtk_box_pack_end(GTK_BOX(hbox), box, FALSE, FALSE, 0);
  
- label = gtk_label_new("Portscan : ");
+ label = gtk_label_new(_("Portscan:"));
  gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE, 0);
  gtk_widget_show(label);
  
- label = gtk_label_new("Checks : ");
+ label = gtk_label_new(_("Checks:"));
  gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE, 0);
  gtk_widget_show(label);
  
@@ -464,7 +447,7 @@ monitor_add_host(ctrls,hostname,port)
  gtk_table_attach_defaults(GTK_TABLE(table), box, 2,3,0,2);
  gtk_widget_show(box);
  
- button = gtk_button_new_with_label("Stop");
+ button = gtk_button_new_with_label(_("Stop"));
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		     (GtkSignalFunc)monitor_stop_test, hostname);
  gtk_box_pack_start(GTK_BOX(box), button, FALSE, FALSE, 0);
@@ -511,8 +494,9 @@ monitor_stop_whole_test(w, ctrls)
  int type = 0, n;
  char * msg;
  char buf[32768];
+ GtkWindow* parent = arg_get_value(ctrls, "PARENT");
+
  network_printf( "CLIENT <|> STOP_WHOLE_TEST <|> CLIENT\n");
- efree(&ArgSock);
  gtk_idle_remove((int)arg_get_value(ctrls, "TAG"));
  
  /*
@@ -531,9 +515,9 @@ monitor_stop_whole_test(w, ctrls)
   efree(&msg);
  }
   
- F_nessusd_running = 0;
  gtk_widget_hide(arg_get_value(ctrls, "WINDOW"));
- report_tests_ng((int)arg_get_value(ctrls, "MONITOR_BACKEND"), 0);
+ arg_set_value(MainDialog, "CONTEXT", -1, parent);
+ report_save(Context, (int)arg_get_value(ctrls, "MONITOR_BACKEND"), NULL);
  return(FALSE);
 }
 
@@ -545,11 +529,10 @@ monitor_stop_whole_test(w, ctrls)
  * data coming from the server. 
  */
 void 
-monitor_input_callback(ctrls, fd, condition)
+monitor_input_callback(ctrls)
     struct arglist * ctrls;
-    int fd;
-    int condition;
 {
+  GtkWindow* parent = arg_get_value(ctrls, "PARENT");
   int finished = 0;
   static char * buf = NULL;
   static int    bufsz = 0;
@@ -567,7 +550,7 @@ monitor_input_callback(ctrls, fd, condition)
   if ((n = strlen (buf)) && buf [n-1] == '\n') buf [n-1] = '\0';
 
   if( buf[0] == '\0') {
-  	if(!is_server_present(GlobalSocket))
+  	if(!is_server_present(Context->socket))
 	{
   	 interrupted++;
    	 goto scan_finished;
@@ -602,11 +585,11 @@ monitor_input_callback(ctrls, fd, condition)
   if(finished)
     {
    scan_finished : 
-      F_nessusd_running = 0;
       gtk_widget_hide(arg_get_value(ctrls, "WINDOW"));
       gtk_idle_remove((int)arg_get_value(ctrls, "TAG"));
       gtk_widget_destroy(arg_get_value(ctrls, "WINDOW"));
-      report_tests_ng((int)arg_get_value(ctrls, "MONITOR_BACKEND"), interrupted);
+      arg_set_value(MainDialog, "CONTEXT", -1, parent);
+      report_save(Context, (int)arg_get_value(ctrls, "MONITOR_BACKEND"), NULL);
     }
 }
  
@@ -658,14 +641,14 @@ static void build_plugins_order_table(order)
   
   for(i=0;i<num;i++)
   {
-   struct arglist * plugs = Plugins;
+   struct arglist * plugs = Context->plugins;
    
    while(plugs && plugs->next && 
         ((int)(arg_get_value(plugs->value, "ID"))!=plugins_order_table_int[i]))
          plugs = plugs->next;
    if(!(plugs && plugs->next))
    {
-    plugs = Scanners;
+    plugs = Context->scanners;
     while(plugs && plugs->next && 
         ((int)(arg_get_value(plugs->value, "ID"))!=plugins_order_table_int[i]))
          plugs = plugs->next;
