@@ -29,6 +29,10 @@
 
 #define DEFAULT_SERVER "localhost"
 #define PROTO_NAME "< NTP/1.2 >< plugins_cve_id plugins_version plugins_bugtraq_id plugins_xrefs timestamps dependencies >\n"
+#ifdef NESSUS_ON_SSL
+# define SSL_VER_DEF_NAME	"TLSv1"
+# define SSL_VER_DEF_METH	TLSv1_client_method
+#endif /* NESSUS_ON_SSL */
 
 #ifdef _CYGWIN_
 extern char * NESSUS_RCFILE;
@@ -38,6 +42,8 @@ extern int init_directories;
 #endif
 
 
-char * connect_to_nessusd(char *, int, char *, char *);
+#include "context.h"
+
+char * connect_to_nessusd(struct context *);
 
 #endif
