@@ -27,6 +27,8 @@
  */
 
 #include <includes.h>
+#include "nessus_i18n.h"
+
 #include "parser.h"
 #include "auth.h"
 #include "error_dialog.h"
@@ -150,6 +152,50 @@ parse_message_type(type)
  return(-1);
 }
 
+/*
+ * parse_server_error
+ *
+ * Feed errors from the Nessus Server
+ * to gettext and display them.
+ */
+void
+parse_server_error(servmsg)
+  char *servmsg;
+{
+  char *msg = parse_separator(servmsg);
+  char *msg1, *msg2;
+
+  /*
+   * msg2 contains the following lines of the server error.
+   * Currently this can only be the list of rejected hosts,
+   * so don't translate them.
+   */
+  if((msg2 = strchr(msg, ';')))
+  {
+    char *t;
+
+    msg2[0] = '\0';
+    msg2++;
+    while((t = strchr(msg2, ';')))
+      t[0]='\n';
+  }
+
+  /* * keep these in sync with the messages in ../nessusd/attack.c */
+  if(!strncmp("E001 -", msg, 6))
+    msg1 = _("Invalid port range");
+  else if(!strncmp("E002 -", msg, 6))
+    msg1 = _("These hosts could not be tested because you"
+	     " are not allowed to do so:");
+  else
+    msg1 = msg;
+
+  if(msg2)
+    show_error("%s\n%s", msg1, msg2);
+  else
+    show_error("%s", msg1);
+  efree(&msg);
+}
+
 /*
  * parse_server_message
  *
@@ -275,20 +321,9 @@ parse_server_message(message, backend, humanmsg)
   	return(MSG_STAT2);
 	break;
   case MSG_ERROR :
-        {
-        if(!F_quiet_mode)
-          {
-           char * msg = parse_separator(t);
-#ifdef USE_GTK
-	   char * t;
-	   while((t = strchr(msg, ';')))t[0]='\n';
-           show_error(msg);
-#endif
-	   efree(&msg);
-  	   return(MSG_ERROR);
-  	  }
+	parse_server_error(t);
+	return(MSG_ERROR);
   	break;
-  	}
   case MSG_PORT :
   	parse_host_add_port(backend, t, humanmsg);
   	return(MSG_PORT);
@@ -587,7 +622,7 @@ parse_separator(str)
  char * ret;
  
  s_1 = parse_symbol(str);
- if(nulstr(s_1))
+ if(!s_1 || s_1[0] == '\0')
    return NULL;
    
  s_2 = parse_symbol(s_1);
