@@ -38,11 +38,12 @@
 #include "prefs_dialog_scan_opt.h"
 #include "globals.h"
 
+#include "../nessus_i18n.h"
+
 static void  scanner_infos_cb(GtkWidget *, struct arglist *);
-     
-     
- 
-struct arglist * prefs_dialog_scan_opt()
+
+struct arglist *prefs_dialog_scan_opt(context)
+  struct context *context;
 {
  GtkWidget * frame;
  GtkWidget * table;
@@ -61,21 +62,21 @@ struct arglist * prefs_dialog_scan_opt()
  
  struct arglist * ctrls = emalloc(sizeof(struct arglist));
  
- frame = gtk_frame_new("Scan options");
+ frame = gtk_frame_new(_("General scan options"));
  gtk_container_border_width(GTK_CONTAINER(frame), 10);
  arg_add_value(ctrls, "FRAME", ARG_PTR, -1, frame);
  
  gtk_widget_show(frame);
  
  
- box = gtk_vbox_new(FALSE, 10);
+ box = gtk_vbox_new(FALSE, 5);
  
  gtk_container_add(GTK_CONTAINER(frame), box);
  gtk_container_border_width(GTK_CONTAINER(box), 10);
  gtk_widget_show(box);
  
  
- ping_hosts = gtk_check_button_new_with_label("Determine if hosts are alive before testing them");
+ ping_hosts = gtk_check_button_new_with_label(_("Determine if hosts are alive before testing them"));
  arg_add_value(ctrls, "PING_HOSTS", ARG_PTR, -1, ping_hosts);
  /*gtk_box_pack_start(GTK_BOX(box), ping_hosts, FALSE, FALSE, 0);
  gtk_widget_show(ping_hosts);*/
@@ -88,7 +89,8 @@ struct arglist * prefs_dialog_scan_opt()
  
 
  gtk_table_set_row_spacing(GTK_TABLE(table), 0, 10);
- label = gtk_label_new("Port range : ");
+ label = gtk_label_new(_("Port range:"));
+ gtk_misc_set_alignment((GtkMisc *)label, 0, 1);
  gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 0,1);
  gtk_widget_show(label);
  
@@ -97,7 +99,7 @@ struct arglist * prefs_dialog_scan_opt()
  gtk_widget_show(port_range);
  arg_add_value(ctrls, "PORT_RANGE", ARG_PTR, -1, port_range);
  
- unscanned_as_closed = gtk_check_button_new_with_label("Consider unscanned ports as closed");
+ unscanned_as_closed = gtk_check_button_new_with_label(_("Consider unscanned ports as closed"));
  arg_add_value(ctrls, "UNSCANNED_CLOSED", ARG_PTR, -1, unscanned_as_closed);
  gtk_table_attach_defaults(GTK_TABLE(table), unscanned_as_closed, 0,2,1,2);
  gtk_widget_show(unscanned_as_closed);
@@ -107,7 +109,8 @@ struct arglist * prefs_dialog_scan_opt()
  
  
  gtk_table_set_row_spacing(GTK_TABLE(table), 1, 10);
- label = gtk_label_new("Number of hosts to test at the same time : ");
+ label = gtk_label_new(_("Number of hosts to test at the same time:"));
+ gtk_misc_set_alignment((GtkMisc *)label, 0, 1);
  gtk_table_attach_defaults(GTK_TABLE(table), label, 0,1,2,3);
  gtk_widget_show(label);
  
@@ -117,7 +120,8 @@ struct arglist * prefs_dialog_scan_opt()
  arg_add_value(ctrls, "MAX_HOSTS", ARG_PTR, -1, entry);
  
  gtk_table_set_row_spacing(GTK_TABLE(table), 2, 10);
- label = gtk_label_new("Number of checks to perform at the same time : ");
+ label = gtk_label_new(_("Number of checks to perform at the same time:"));
+ gtk_misc_set_alignment((GtkMisc *)label, 0, 1);
  gtk_table_attach_defaults(GTK_TABLE(table), label, 0,1,3,4);
  gtk_widget_show(label);
  
@@ -128,7 +132,8 @@ struct arglist * prefs_dialog_scan_opt()
  
  
 
- label = gtk_label_new("Path to the CGIs : ");
+ label = gtk_label_new(_("Path to the CGIs:"));
+ gtk_misc_set_alignment((GtkMisc *)label, 0, 1);
  gtk_table_attach_defaults(GTK_TABLE(table), label, 0,1,4,5);
  gtk_widget_show(label);
  
@@ -138,86 +143,27 @@ struct arglist * prefs_dialog_scan_opt()
  arg_add_value(ctrls, "CGI_PATH", ARG_PTR, -1, entry);
  
  
- reverse_lookup = gtk_check_button_new_with_label("Do a reverse lookup on the IP before testing it");
+ reverse_lookup = gtk_check_button_new_with_label(_("Do a reverse lookup on the IP before testing it"));
  arg_add_value(ctrls, "REVERSE_LOOKUP", ARG_PTR, -1, reverse_lookup);
  gtk_box_pack_start(GTK_BOX(box), reverse_lookup, FALSE, FALSE, 0);
  gtk_widget_show(reverse_lookup);
  
- optimize_test = gtk_check_button_new_with_label("Optimize the test");
+ optimize_test = gtk_check_button_new_with_label(_("Optimize the test"));
  arg_add_value(ctrls, "OPTIMIZE_TEST", ARG_PTR, -1, optimize_test);
  gtk_box_pack_start(GTK_BOX(box), optimize_test, FALSE, FALSE, 0);
  gtk_widget_show(optimize_test);
  
  
- safe_checks = gtk_check_button_new_with_label("Safe checks");
+ safe_checks = gtk_check_button_new_with_label(_("Safe checks"));
  arg_add_value(ctrls, "SAFE_CHECKS", ARG_PTR, -1, safe_checks);
  gtk_box_pack_start(GTK_BOX(box), safe_checks, FALSE, FALSE, 0);
  gtk_widget_show(safe_checks);
  
- use_mac_addr = gtk_check_button_new_with_label("Designate hosts by their MAC address");
+ use_mac_addr = gtk_check_button_new_with_label(_("Designate hosts by their MAC address"));
  arg_add_value(ctrls, "USE_MAC_ADDR", ARG_PTR, -1, use_mac_addr);
  gtk_box_pack_start(GTK_BOX(box), use_mac_addr, FALSE, FALSE, 0);
  gtk_widget_show(use_mac_addr);
  
-
-#ifdef ENABLE_SAVE_KB
-#if 0
- opt = gtk_check_button_new_with_label("Detached scan");
- arg_add_value(ctrls, "DETACHED_SCAN", ARG_PTR, -1, opt);
- gtk_box_pack_start(GTK_BOX(box), opt, FALSE, FALSE, 0);
- gtk_widget_show(opt);
- gtk_signal_connect(GTK_OBJECT(opt),
-		     "clicked",
-		     GTK_SIGNAL_FUNC(detached_cb),
-		     ctrls);
- 
- hbox = gtk_hbox_new(TRUE, TRUE);
- /*gtk_container_set_border_width(GTK_CONTAINER(hbox), 5); */
- gtk_box_pack_start(GTK_BOX(box), hbox, TRUE, TRUE, 0);
- gtk_widget_show(hbox);
- label = gtk_label_new("Send results to this email address : ");
- arg_add_value(ctrls, "EMAIL_ADDR_LABEL", ARG_PTR, -1, label);
- gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
- gtk_widget_set_sensitive(label, FALSE);
- gtk_widget_show(label);
- 
- entry = gtk_entry_new();
- arg_add_value(ctrls, "EMAIL_ADDR", ARG_PTR, -1, entry);
- gtk_box_pack_start(GTK_BOX(hbox), entry, FALSE, FALSE, 0);
- gtk_widget_set_sensitive(entry, FALSE);
- gtk_widget_show(entry);
- 
- 
- opt = gtk_check_button_new_with_label("Continuous scan");
- arg_add_value(ctrls, "CONTINUOUS_SCAN", ARG_PTR, -1, opt);
- gtk_box_pack_start(GTK_BOX(box), opt, FALSE, FALSE, 0);
- gtk_widget_set_sensitive(opt, FALSE);
- gtk_widget_show(opt);
- gtk_signal_connect(GTK_OBJECT(opt),
-		     "clicked",
-		     GTK_SIGNAL_FUNC(continuous_cb),
-		     ctrls);
- 
- hbox = gtk_hbox_new(TRUE, TRUE);
- /*gtk_container_set_border_width(GTK_CONTAINER(hbox), 5); */
- gtk_box_pack_start(GTK_BOX(box), hbox, TRUE, TRUE, 0);
- gtk_widget_show(hbox);
- 
- 
- label = gtk_label_new("Delay between two scans : ");
- arg_add_value(ctrls, "DELAY_LABEL", ARG_PTR, -1, label);
- gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
- gtk_widget_set_sensitive(label, FALSE);
- gtk_widget_show(label);
- 
- 
- opt = gtk_entry_new();
- arg_add_value(ctrls, "DELAY",  ARG_PTR, -1, opt);
- gtk_box_pack_start(GTK_BOX(hbox), opt, TRUE, TRUE, 0);
- gtk_widget_set_sensitive(opt, FALSE);
- gtk_widget_show(opt);
-#endif
-#endif
  scanners_window = gtk_scrolled_window_new(NULL,NULL);
  gtk_container_border_width(GTK_CONTAINER(scanners_window), 0);
  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scanners_window),	
@@ -225,17 +171,14 @@ struct arglist * prefs_dialog_scan_opt()
  gtk_box_pack_end(GTK_BOX(box), scanners_window, TRUE, TRUE, 0);
  gtk_widget_show(scanners_window); 
  
- label = gtk_label_new("Port scanner : ");
+ label = gtk_label_new(_("Port scanner:"));
  gtk_box_pack_end(GTK_BOX(box), label, FALSE, FALSE, 0);
+ gtk_misc_set_alignment((GtkMisc *)label, 0, 1);
  gtk_widget_show(label);
  
  list = gtk_list_new();
  arg_add_value(ctrls, "SCANNERS_LIST", ARG_PTR, -1, list);
-#if GTK_VERSION < 11
- gtk_container_add(GTK_CONTAINER(scanners_window), list);
-#else
  gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scanners_window), list);
-#endif
  gtk_signal_connect(GTK_OBJECT(list),
 		     "selection_changed",
 		     GTK_SIGNAL_FUNC(scanner_infos_cb),     
@@ -243,8 +186,7 @@ struct arglist * prefs_dialog_scan_opt()
                      
                      
  gtk_widget_show(list);
- fill_scanner_list(ctrls);
- arg_add_value(ctrls, "SCANNERS_NUM", ARG_INT, sizeof(int), (void *)ScannersNum);
+ fill_scanner_list(context, ctrls);
  return(ctrls);
 }
 
@@ -255,15 +197,15 @@ void prefs_scanner_list_toggle_callback(w, scanner)
 {
   int state = GTK_TOGGLE_BUTTON(w)->active;
   plug_set_launch(scanner,state);
-  pluginset_reload(Plugins, Scanners);
 }
 
 void 
-fill_scanner_list(ctrls)
- struct arglist * ctrls;
+fill_scanner_list(context, ctrls)
+  struct context *context;
+  struct arglist *ctrls;
 {
  GtkTooltips * tooltips;
- struct arglist * scans = Scanners;
+ struct arglist * scans = context->scanners;
  GList * dlist = NULL;
 
  dlist = arg_get_value(ctrls, "DLIST");
@@ -316,21 +258,6 @@ fill_scanner_list(ctrls)
    gtk_list_append_items(GTK_LIST(arg_get_value(ctrls, "SCANNERS_LIST")), dlist);
 }
 
-int prefs_scanner_redraw(w, dumb, ctrls)
- GtkWidget * w;
- void * dumb;
- struct arglist * ctrls;
-{
- int num;
- 
- num = (int)arg_get_value(ctrls, "SCANNERS_NUM");
- if(num != ScannersNum){
-  fill_scanner_list(ctrls);
-  arg_set_value(ctrls, "SCANNERS_NUM", sizeof(int), (void *)ScannersNum);
-  }
- return 0;
-}
-
 
 static void 
 scanner_infos_cb(widget, ctrls)
@@ -347,6 +274,6 @@ scanner_infos_cb(widget, ctrls)
   
   list_item = GTK_OBJECT(dlist->data);
   scanner = gtk_object_get_data(list_item,"list_item_data");
-  plugin_info_window_setup(Scanners, scanner);             
+  plugin_info_window_setup(Context->scanners, scanner);             
 }
 #endif
