@@ -19,7 +19,8 @@
 #ifndef _NESSUSC_PREFS_DIALOG_SCAN_OPT_H
 #define _NESSUSC_PREFS_DIALOG_SCAN_OPT_H
 
-struct arglist * prefs_dialog_scan_opt();
-int prefs_scanner_redraw(GtkWidget * , void *, struct arglist *);
-void  fill_scanner_list(struct arglist *);
+#include "context.h"
+
+struct arglist *prefs_dialog_scan_opt(struct context *);
+void fill_scanner_list(struct context *, struct arglist *);
 #endif
