@@ -19,6 +19,7 @@
 #ifndef _NESSUSC_PREFS_DIALOG_USER_H
 #define _NESSUSC_PREFS_DIALOG_USER_H
 
-struct arglist * prefs_dialog_user(struct arglist *);
+void fill_rules_list(struct context *, struct arglist *);
+struct arglist *prefs_dialog_user();
 
 #endif
