@@ -19,7 +19,5 @@
 #ifndef _NESSUSC_PREFS_TARGET_H
 #define _NESSUSC_PREFS_TARGET_H
 
-struct arglist * prefs_dialog_target(struct arglist *);
-void prefs_dialog_target_free_list(struct arglist*);
-void prefs_dialog_target_fill_sessions(struct arglist*, harglst*);
+struct arglist *prefs_dialog_target();
 #endif
