@@ -18,11 +18,20 @@
  
 #ifndef _NESSUSC_REPORT_H
 #define _NESSUSC_REPORT_H
+
 #define HOLE_PRESENT 3
 #define WARNING_PRESENT 2
 #define NOTE_PRESENT 1
-void report_tests(struct arglist *, int);
+
+#include "context.h"
+
+char *report_get_filename(struct context *);
 int is_there_any_hole(struct arglist *);
+
+#ifdef USE_GTK
+void report_save(struct context *, int, const char *);
+void open_report_selectfile(void);
+#endif
+
 #endif
 
-void open_report_selectfile(void);
