@@ -41,6 +41,7 @@
 
 
 #include <includes.h>
+#include "nessus_i18n.h"
 #include <stdarg.h>
 
 #include "report.h"
@@ -48,6 +49,8 @@
 #include "backend.h"
 #include "data_mining.h"
 #include "globals.h"
+#include "context.h"
+#include "preferences.h"
 #include "report_utils.h"
 
 int backend_to_xml_ng (int, char *);
@@ -184,21 +187,12 @@ xml_fprintf_element (FILE *fd, int indent, char *tag, char *value)
 static void
 xml_info_host (int be, FILE* fd, int indent, struct arglist * t)
 {
- xml_fprintf (fd, indent, "<host>\n");
- if (First_time)
- {
-  t = Prefs;
-  if (t)
-  {
-   xml_fprintf_element (
-    fd, indent+1, "name", (char *) arg_get_value (t, "nessusd_host")); 
-  }
- }
- else
-  xml_fprintf (fd, indent+1, 
-   "<error txt=\"No server name information (not connected ?).\"/>\n");
+ const char *host = prefs_get_string(Context, "nessusd_host");
 
- t = arg_get_value(Prefs, "SERVER_INFO");
+ xml_fprintf (fd, indent, "<host>\n");
+ xml_fprintf_element(fd, indent+1, "name", (char*)host);
+
+ t = arg_get_value(Context->prefs, "SERVER_INFO");
  if (t)
  {
   xml_fprintf_element (fd, indent+1, "osname", (char *) arg_get_value (t, "server_info_os"));
@@ -259,20 +253,19 @@ static void
 xml_info (int be, FILE* fd, int indent)
 {
  struct arglist * t;
- t = arg_get_value(Prefs, "SERVER_INFO");
+ t = arg_get_value(Context->prefs, "SERVER_INFO");
 
  if (t)
  {
-  xml_fprintf (fd, indent, "<info>\n");
+  xml_fprintf (fd, 2, "<info>\n");
    xml_info_nessusd(be, fd, indent+1, t);
    xml_info_host(be, fd, indent+1, t);
    xml_info_date(be, fd, indent+1, t);
-  xml_fprintf (fd, indent, "</info>\n");
+  xml_fprintf (fd, 2, "</info>\n\n");
  } else {
-  fprintf (stderr, "xml_output: No SERVER_INFO found.\n");
-  xml_fprintf (fd, indent, "<info>\n");
+  xml_fprintf (fd, 2, "<info>\n");
    xml_fprintf (fd, indent+1, "<!-- no version information found -->");
-  xml_fprintf (fd, indent, "</info>\n");
+  xml_fprintf (fd, 2, "</info>\n\n");
  }
 } /* xml_info */
 
@@ -287,7 +280,7 @@ xml_config_scanners (FILE* fd, int indent, struct arglist* t)
         efree(&esc_name);
 	t = t->next;
   }
-  xml_fprintf (fd, indent, "</scanners>\n");
+  xml_fprintf (fd, indent, "</scanners>\n\n");
 } /* xml_config_scanners */
 
 static void
@@ -295,7 +288,7 @@ xml_config_global_pref (FILE* fd, int indent, char *name, char *value)
 {
   char* esc_name = escape_string(name);
   char* esc_value = escape_string(value);
-  xml_fprintf (fd, indent, 
+  xml_fprintf (fd, indent+1, 
    "<pref name=\"%s\" value=\"%s\" />\n", esc_name, esc_value);
   efree(&esc_name);
   efree(&esc_value);
@@ -304,8 +297,8 @@ xml_config_global_pref (FILE* fd, int indent, char *name, char *value)
 static void
 xml_config_global (FILE* fd, int indent, struct arglist* t)
 {
-  xml_fprintf (fd, indent, "<global>\n");
-  while( t->next != NULL )
+  xml_fprintf (fd, indent, "<global> ");
+  while(t && t->next)
   {
     if (t->type == ARG_STRING) {
       xml_config_global_pref(fd, indent+1, t->name, t->value);
@@ -314,7 +307,7 @@ xml_config_global (FILE* fd, int indent, struct arglist* t)
     }
     t = t->next;
   } /* while */
-  xml_fprintf (fd, indent, "</global>\n");
+  fprintf (fd, "</global>\n");
 } /* xml_config_global */
 
 static void
@@ -340,7 +333,7 @@ xml_config_plugins (FILE* fd, int indent, struct arglist* t)
      xml_setting (fd, indent+1, t->name, (t->value?"yes":"no"));
    t = t->next;
   }
-  xml_fprintf (fd, indent, "</plugins>\n");
+  xml_fprintf (fd, indent, "</plugins>\n\n");
 } /* xml_config_server */
 
 static void
@@ -358,7 +351,7 @@ xml_config_server (FILE* fd, int indent, struct arglist* t)
   }
    t = t->next;
   }
-  xml_fprintf (fd, indent, "</server>\n");
+  xml_fprintf (fd, indent, "</server>\n\n");
 } /* xml_config_server */
 
 static void
@@ -368,31 +361,27 @@ xml_config (FILE* fd, int indent)
   
   xml_fprintf (fd, indent, "<config>\n");
 
-  t = Prefs;
-  if (t)
-  {
-   xml_config_global (fd, indent+1, t);
-  }
+  xml_config_global (fd, indent+1, Context->prefs);
 
-  t = arg_get_value(Prefs, "SCANNER_SET");
+  t = arg_get_value(Context->prefs, "SCANNER_SET");
   if (t)
   {
    xml_config_scanners(fd, indent+1, t);
   }
 
-  t = arg_get_value(Prefs, "SERVER_PREFS");
+  t = arg_get_value(Context->prefs, "SERVER_PREFS");
   if (t)
   {
    xml_config_server(fd, indent+1, t);
   }
 
-  t = arg_get_value(Prefs, "PLUGINS_PREFS");
+  t = arg_get_value(Context->prefs, "PLUGINS_PREFS");
   if (t)
   {
    xml_config_plugins(fd, indent+1, t);
   }
 
-  xml_fprintf (fd, indent, "</config>\n");
+  xml_fprintf (fd, indent, "</config>\n\n");
 }
 
 static void 
@@ -409,7 +398,7 @@ xml_plugins_plugin (FILE* fd, int indent, struct arglist * u)
      xml_fprintf_element (fd, indent+1, "risk",  getrisk((char*)arg_get_value (u, "DESCRIPTION")));
      xml_fprintf_element (fd, indent+1, "summary", arg_get_value (u, "SUMMARY"));
      xml_fprintf_element (fd, indent+1, "copyright", (char *) arg_get_value (u, "COPYRIGHT"));
-     xml_fprintf (fd, indent, "</plugin>\n");
+     xml_fprintf (fd, indent, "</plugin>\n\n");
 } /* xml_plugins_plugin */
 
 static void 
@@ -419,24 +408,7 @@ xml_plugins (FILE* fd, int indent)
 
  xml_fprintf (fd, indent, "<plugins>\n");
 
-  t = Scanners;
-  if (t && t->type == ARG_ARGLIST)
-  {
-  while (t->next)
-  {
-     struct arglist * u = t->value;
-     if (arg_get_value (u, "ENABLED"))
-     {
-      xml_plugins_plugin(fd, indent+1, u);
-     }
-
-    t = t->next;
-    }
-  }
-  else
-   xml_fprintf (fd, indent+1, "<error txt=\"No scanners list.\"/>\n");
-
-  t = Plugins;
+  t = Context->plugins;
   if (t && t->type == ARG_ARGLIST)
   {
   while (t->next)
@@ -453,7 +425,7 @@ xml_plugins (FILE* fd, int indent)
   else
    xml_fprintf (fd, indent+1, "<error txt=\"No plugins list.\"/>\n");
 
-  xml_fprintf (fd, indent, "</plugins>\n");
+  xml_fprintf (fd, indent, "</plugins>\n\n");
 }
 
 
@@ -471,7 +443,7 @@ getrisk (char * str)
  }
  else
  {
-  return strcpy (bck, "Unknown");
+  return strcpy (bck, "WARNING: no 'Risk Factor' found !");
  }
 }
 
@@ -708,7 +680,7 @@ xml_results ( FILE* fd, int indent, int be)
   q = subset_next(q);
  }
 
- xml_fprintf (fd, indent, "</results>\n");
+ xml_fprintf (fd, indent, "</results>\n\n");
  subset_free(sq);
 } /* xml_results */
 
@@ -720,7 +692,7 @@ int backend_to_xml_ng(be, filename)
 
  if(!fd)
  {
-  show_error(strerror(errno));
+  show_error(_("Can't open %s for writing: %s."), strerror(errno));
   return -1;
  }
 
