@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2006 Tenable Network Security, Inc.
+ * Copyright (C) 1998 - 2004 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -86,7 +86,7 @@ static void
 attack_sigterm()
 {
  hosts_stop_all();
- wait_for_children1();
+ wait_for_children();
 }
 
 
@@ -182,7 +182,7 @@ launch_plugin(globals, sched, plugin, hostname, cur_plug, num_plugs, hostinfos,
   strncpy(name, plug_get_path(args), sizeof(name) - 1);
   name[sizeof(name) - 1 ] = '\0';
 
-  if(plug_get_launch(args) != LAUNCH_DISABLED || 
+  if(plug_get_launch(args) || 
      category == ACT_INIT ||
     (category == ACT_SETTINGS)) /* can we launch it ? */
   {
@@ -282,10 +282,10 @@ launch_plugin(globals, sched, plugin, hostname, cur_plug, num_plugs, hostinfos,
 	  				attack_user_name(globals),
 	  				hostname);
 	  pluginlaunch_stop();		
-	  if(new_kb)save_kb_close(globals, hostname, inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP")));
+	  if(new_kb)save_kb_close(globals, hostname);	
 	  if(kb_item_get_int(kb, "Host/ping_failed") > 0)
 	  {
-	   save_kb_restore_backup(globals, hostname, inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP")));
+	   save_kb_restore_backup(globals, hostname);
 	  }
 	  
 	  plugin_set_running_state(sched, plugin, PLUGIN_STATUS_DONE);				
@@ -342,16 +342,16 @@ attack_host      (globals, hostinfos, hostname,  sched)
   
   if(save_kb(globals))
   {
-   if( save_kb_exists(globals, hostname,  inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP"))) != 0 && 
+   if( save_kb_exists(globals, hostname) != 0 && 
        save_kb_pref_restore(globals) != 0 )
      {
-      save_kb_backup(globals, hostname, inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP")));
-      kb = save_kb_load_kb(globals, hostname, inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP")));
+      save_kb_backup(globals, hostname);
+      kb = save_kb_load_kb(globals, hostname);
       kb_restored = 1; 
      }
    else 
     {
-     save_kb_new(globals, hostname, inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP")));
+     save_kb_new(globals, hostname);
      kb = kb_new();
      new_kb = 1;
     }
@@ -422,7 +422,7 @@ host_died:
   arg_free(tmp); 
   pluginlaunch_stop();
   plugins_scheduler_free(sched);
-  if(new_kb)save_kb_close(globals, hostname, inet_ntoa(*(struct in_addr *)arg_get_value(hostinfos, "IP")));
+  if(new_kb)save_kb_close(globals, hostname);
 }
 
 /*-----------------------------------------------------------------
@@ -540,16 +540,13 @@ attack_network(globals)
   int  save_session= 0;  
   int continuous   = 0;
   int detached     = 0;
+  hargwalk *  hw;
+  harglst * files;
+  char * key;
   int return_code = 0;
   char * port_range;
   plugins_scheduler_t sched;
   int fork_retries = 0;
-  harglst * files;
-  hargwalk * hw;
-  char * key;
-  struct timeval then, now;
-
-  gettimeofday(&then, NULL);
 
   host_ip.s_addr = 0;
   preferences    = arg_get_value(globals, "preferences");
@@ -640,7 +637,7 @@ start_attack_network:
   /*
    * Initialization of the attack
    */
-  sched  = plugins_scheduler_init(plugins,  preferences_autoload_dependencies(preferences), preferences_silent_dependencies(preferences) ); 
+  sched  = plugins_scheduler_init(plugins,  preferences_autoload_dependencies(preferences) ); 
   
   
   hg_flags = preferences_get_host_expansion(preferences);
@@ -707,7 +704,7 @@ start_attack_network:
     {
     if(save_kb_pref_tested_hosts_only(globals))
     {
-      if(!save_kb_exists(globals, hostname, inet_ntoa(host_ip)))
+    if(!save_kb_exists(globals, hostname))
      {
       log_write("user %s : not testing %s because it has never been tested before\n",
       		 attack_user_name(globals), 
@@ -724,7 +721,7 @@ start_attack_network:
    else if(save_kb_pref_untested_hosts_only(globals))
    {
     /* XXX */
-    if(save_kb_exists(globals, hostname, inet_ntoa(host_ip)))
+    if(save_kb_exists(globals, hostname))
     {
      log_write("user %s : not testing %s because it has already been tested before\n", 
      			attack_user_name(globals), 
@@ -905,10 +902,6 @@ stop:
   	goto start_attack_network;
 	}
   else if(detached)detached_end_session(globals);	
-
-
-  gettimeofday(&now, NULL);
-  log_write("Total time to scan all hosts : %ld seconds\n", now.tv_sec - then.tv_sec);
   
   return return_code;
 }
