@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2006 Tenable Network Security, Inc.
+ * Copyright (C) 1999 - 2003 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -38,7 +38,6 @@ static pl_class_t* nasl_plugin_init(struct arglist* prefs,
 
 static void nasl_thread(struct arglist *);
 
-
 /*
  *  Add *one* .nasl plugin to the plugin list
  */
@@ -83,28 +82,18 @@ nasl_plugin_add(folder, name, plugins, preferences)
   }
  plug_set_path(plugin_args, fullname);
  if(plug_get_id(plugin_args) > 0)
-	{
- 	 store_plugin(plugin_args, name);
- 	 plugin_args = store_load_plugin(folder, name, preferences);
- 	}
-	 
+ 	plugin_args = store_plugin(plugin_args, name);
  }
  
-  if ( plugin_args == NULL ) 
-	{
-       /* Discard invalid plugins */
-	fprintf(stderr, "%s failed to load\n", name);
-	return NULL;
-	}
-
  if(plug_get_id(plugin_args) == 0)
  {
+  /* Discard invalid plugins */
   plugin_free(plugin_args);
   return NULL;
  }
  
  
- plug_set_launch(plugin_args, LAUNCH_DISABLED);
+ plug_set_launch(plugin_args, 0);
  prev_plugin = arg_get_value(plugins, name);
  if( prev_plugin == NULL )
   arg_add_value(plugins, name, ARG_ARGLIST, -1, plugin_args);
@@ -193,35 +182,35 @@ nasl_thread(g_args)
  {
   close(i);
  }
- #ifdef RLIMIT_RSS	 
-  {	 
-  struct rlimit rlim;	 
-  getrlimit(RLIMIT_RSS, &rlim);	 
-  rlim.rlim_cur = 1024*1024*512;	 
-  rlim.rlim_max = 1024*1024*512;	 
-  setrlimit(RLIMIT_RSS, &rlim);	 
-  }	 
- #endif	 
- 	 
- #ifdef RLIMIT_AS	 
-  {	 
-  struct rlimit rlim;	 
-  getrlimit(RLIMIT_AS, &rlim);	 
-  rlim.rlim_cur = 1024*1024*512;	 
-  rlim.rlim_max = 1024*1024*512;	 
-  setrlimit(RLIMIT_AS, &rlim);	 
-  }	 
- #endif	 
- 	 
- #ifdef RLIMIT_DATA	 
-  {	 
-  struct rlimit rlim;	 
-  getrlimit(RLIMIT_DATA, &rlim);	 
-  rlim.rlim_cur = 1024*1024*512;	 
-  rlim.rlim_max = 1024*1024*512;	 
-  setrlimit(RLIMIT_DATA, &rlim);	 
-  }	 
- #endif
+#ifdef RLIMIT_RSS
+ {
+ struct rlimit rlim;
+ getrlimit(RLIMIT_RSS, &rlim);
+ rlim.rlim_cur = 1024*1024*20;
+ rlim.rlim_max = 1024*1024*20;
+ setrlimit(RLIMIT_RSS, &rlim);
+ }
+#endif
+
+#ifdef RLIMIT_AS
+ {
+ struct rlimit rlim;
+ getrlimit(RLIMIT_AS, &rlim);
+ rlim.rlim_cur = 1024*1024*20;
+ rlim.rlim_max = 1024*1024*20;
+ setrlimit(RLIMIT_AS, &rlim);
+ }
+#endif
+
+#ifdef RLIMIT_DATA
+ {
+ struct rlimit rlim;
+ getrlimit(RLIMIT_DATA, &rlim);
+ rlim.rlim_cur = 1024*1024*20;
+ rlim.rlim_max = 1024*1024*20;
+ setrlimit(RLIMIT_DATA, &rlim);
+ }
+#endif
  setproctitle("testing %s (%s)", (char*)arg_get_value(arg_get_value(args, "HOSTNAME"), "NAME"), (char*)arg_get_value(g_args, "name"));
  signal(SIGTERM, _exit);
  
