@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2006 Tenable Network Security, Inc.
+ * Copyright (C) 1999 - 2003 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -164,8 +164,7 @@ nes_plugin_add(folder, name, plugins, preferences)
 	if(e >= 0)
 	{  
 	 plug_set_path(args, fullname);
-	 store_plugin(args, name); 
- 	 args = store_load_plugin(folder, name, preferences);
+	 args =  store_plugin(args, name); 
 	}
 	else
 	{
@@ -182,7 +181,7 @@ nes_plugin_add(folder, name, plugins, preferences)
   if( args != NULL )
   {
    prev_plugin = arg_get_value(plugins, name);
-   plug_set_launch(args, LAUNCH_DISABLED);
+   plug_set_launch(args, 0);
    if( prev_plugin == NULL )
           arg_add_value(plugins, name, ARG_ARGLIST, -1, args);
     else
@@ -212,10 +211,7 @@ nes_plugin_launch(globals, plugin, hostinfos, preferences, kb, name)
  
  ptr = LOAD_LIBRARY(name);
  if( ptr == NULL)
-	{
-    	log_write("Couldn't load %s - %s\n", name, LIB_LAST_ERROR());
  	return -1;
-	}
 	
 	
  func = (plugin_run_t)LOAD_FUNCTION(ptr, "plugin_run");
@@ -265,7 +261,39 @@ static int nes_thread(args)
  {
     close(i);
  }
+
  
+#ifdef RLIMIT_RSS
+ {
+ struct rlimit rlim;
+ getrlimit(RLIMIT_RSS, &rlim);
+ rlim.rlim_cur = 1024*1024*40;
+ rlim.rlim_max = 1024*1024*40;
+ setrlimit(RLIMIT_RSS, &rlim);
+ }
+#endif
+
+#ifdef RLIMIT_AS
+ {
+ struct rlimit rlim;
+ getrlimit(RLIMIT_AS, &rlim);
+ rlim.rlim_cur = 1024*1024*40;
+ rlim.rlim_max = 1024*1024*40;
+ setrlimit(RLIMIT_AS, &rlim);
+ }
+#endif
+
+#ifdef RLIMIT_DATA
+ {
+ struct rlimit rlim;
+ getrlimit(RLIMIT_DATA, &rlim);
+ rlim.rlim_cur = 1024*1024*40;
+ rlim.rlim_max = 1024*1024*40;
+ setrlimit(RLIMIT_DATA, &rlim);
+ }
+#endif
+
+
  setproctitle("testing %s (%s)", (char*)arg_get_value(arg_get_value(args, "HOSTNAME"), "NAME"), (char*)arg_get_value(args, "name"));
  func = arg_get_value(args, "func");
  signal(SIGTERM, _exit);
