@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2006 Tenable Network Security, Inc.
+ * Copyright (C) 1998 - 2004 Renaud Deraison
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -41,7 +41,6 @@ struct running {
 	plugins_scheduler_t sched;
 	struct timeval start;
 	int timeout;
- 	int launch_status;
 	int upstream_soc;
 	int internal_soc;
 	int alive;
@@ -84,12 +83,7 @@ static int process_internal_msg(int p)
  if ( type & INTERNAL_COMM_MSG_SHARED_SOCKET )
    e = shared_socket_process(processes[p].internal_soc, processes[p].pid, buffer, type);
  else if ( type & INTERNAL_COMM_MSG_TYPE_DATA )
-   {
-   if ( processes[p].launch_status != LAUNCH_SILENT )
-    e = internal_send(processes[p].upstream_soc, buffer, type);
-   else
-    e = 0;
-   }
+   e = internal_send(processes[p].upstream_soc, buffer, type);
  else if ( type & INTERNAL_COMM_MSG_TYPE_KB )
    {
    e = 0;
@@ -421,7 +415,6 @@ plugin_launch(globals, sched, plugin, hostinfos, preferences, kb, name, launcher
  processes[p].plugin  = plugin;
  processes[p].sched   = sched;
  processes[p].name    = plugin->arglist->name;
- processes[p].launch_status = plug_get_launch(plugin->arglist->value);
  processes[p].timeout = preferences_plugin_timeout(preferences, plug_get_id(plugin->arglist->value));
  if( processes[p].timeout == 0)
    processes[p].timeout = plugin->timeout;
