@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2006 Tenable Network Security, Inc.
+ * Copyright (C) 1998 - 2004 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -25,7 +25,6 @@
 #include "pluginscheduler.h"
 #include "pluginload.h"
 #include "pluginlaunch.h"
-#include "preferences.h"
 #include "log.h"
 
 
@@ -53,13 +52,13 @@ void plugin_set_running_state(plugins_scheduler_t shed, struct scheduler_plugin
 static unsigned int mkhash(char * name)
 {
   int i;
-  unsigned int h = 0;
+  int h = 0;
   
   for(i=0; name[i] != '\0' ;i++)
-   h += name[i]; 
+   h = ((h * 128) + name[i]) % HASH_MAX;
    
  
-  return h % HASH_MAX;
+  return h;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -214,7 +213,10 @@ static void hash_link_destroy(struct hash * h)
   efree(&h->dependencies);
  }
 
- efree(&h->dependencies_ptr);
+ arg_free_all(h->plugin->required_ports);
+ arg_free_all(h->plugin->required_udp_ports);
+ arg_free_all(h->plugin->required_keys);
+ arg_free_all(h->plugin->excluded_keys);
  efree(&h->plugin);
  
  if( h->ports != NULL )
@@ -250,11 +252,9 @@ static int hash_add(struct hash * h, char * name, struct scheduler_plugin * plug
  int num_deps = 0;
  
  l->plugin = plugin;
- l->plugin->parent_hash = l;
  l->name   = name;
  l->next = h[idx].next;
  h[idx].next = l;
- l->dependencies_ptr = NULL;
  
  if( deps == NULL )
   l->dependencies = NULL;
@@ -275,9 +275,7 @@ static int hash_add(struct hash * h, char * name, struct scheduler_plugin * plug
    l->num_deps ++;
    al = al->next;
   }
-#if 0
   arg_free_all(deps);
-#endif
  }
  
  if( ports == NULL )
@@ -300,13 +298,13 @@ static int hash_add(struct hash * h, char * name, struct scheduler_plugin * plug
     l->ports[i++] = cache_inc(al->name);
     al = al->next;
    }
+   arg_free_all(ports);
   }
  return 0;
 }
 
 
 
-
 static struct hash * _hash_get(struct hash * h, char * name)
 {
  unsigned int idx = mkhash(name);
@@ -321,37 +319,38 @@ static struct hash * _hash_get(struct hash * h, char * name)
  return NULL;
 }
 
+static struct scheduler_plugin * hash_get(struct hash * h, char * name)
+{
+ struct hash * l = _hash_get(h, name);
+ if(  l == NULL )
+  return NULL;
+ else
+  return l->plugin;
+}
 
-static struct hash ** hash_get_deps_ptr(struct hash * h, char * name)
+static char ** hash_get_ports(struct hash * h, char * name)
+{
+ struct hash * l = _hash_get(h, name);
+ if( l == NULL)
+  return NULL;
+ else
+  return l->ports;
+}
+
+
+static char ** hash_get_deps(struct hash * h, char * name)
 {
  struct hash * l = _hash_get(h, name);
  
  if( l == NULL )
   return NULL;
  
- if( l->dependencies_ptr == NULL )
+ if( l->dependencies == NULL )
   return NULL;
  
- return l->dependencies_ptr;
+ return l->dependencies;
 }
 
-static void hash_fill_deps(struct hash * h, struct hash * l )
-{
- int i, j = 0;
- if ( l->num_deps != 0 )
- {
-  l->dependencies_ptr = emalloc((1 + l->num_deps) * sizeof(struct hash*));
-  for ( i = 0 ; l->dependencies[i] ; i ++ )
-	{
-	struct hash * d = _hash_get(h, l->dependencies[i]);
-	if ( d != NULL )
-	 l->dependencies_ptr[j++] = d;
-        else
-          log_write("%s depends on %s which could not be found\n", l->plugin->arglist->name, l->dependencies[i]);
-	}
-   l->dependencies_ptr[j] = NULL;
-  }
-}
 
 /*----------------------------------------------------------------------*/
 
@@ -378,7 +377,7 @@ struct plist * pl_get(struct plist * list, char * name)
 
 void scheduler_mark_running_ports(plugins_scheduler_t sched, struct scheduler_plugin * plugin)
 {
- char ** ports = plugin->parent_hash->ports;
+ char ** ports = hash_get_ports(sched->hash, plugin->arglist->name);
  int i;
  
  if( ports == NULL )
@@ -409,8 +408,9 @@ void scheduler_rm_running_ports(plugins_scheduler_t sched, struct scheduler_plug
  char ** ports; 
  int i;
 
+
  
- ports = plugin->parent_hash->ports;
+ ports = hash_get_ports(sched->hash, plugin->arglist->name);
 
  
  if( ports == NULL )
@@ -489,18 +489,19 @@ void scheduler_plugin_best_score(plugins_scheduler_t sched, int *bscore, struct
 
 
 
-struct scheduler_plugin * plugin_next_unrun_dependencie(plugins_scheduler_t sched, struct hash ** dependencies_ptr, int already_in_dependencie)
+struct scheduler_plugin * plugin_next_unrun_dependencie(plugins_scheduler_t sched, char ** dependencies, int already_in_dependencie)
 {
+ struct hash * h = sched->hash;
  int flag = 0;
  int counter = 0;
  int i;
  
- if(dependencies_ptr == NULL)
+ if(dependencies == NULL)
   return NULL;
   
- for(i=0;dependencies_ptr[i] != NULL;i++)
+ for(i=0;dependencies[i] != NULL;i++)
   {
-   struct scheduler_plugin * plugin = dependencies_ptr[i]->plugin;
+   struct scheduler_plugin * plugin = hash_get(h, dependencies[i]);
    if(plugin != NULL)
    {
     int state = plugin_get_running_state(plugin);
@@ -508,14 +509,14 @@ struct scheduler_plugin * plugin_next_unrun_dependencie(plugins_scheduler_t sche
     {
      case PLUGIN_STATUS_UNRUN :
      	{
-	struct hash ** deps_ptr = dependencies_ptr[i]->dependencies_ptr;
+	char ** deps = hash_get_deps(h, plugin->arglist->name);
 	struct scheduler_plugin * ret;
 	counter ++;
-	if(deps_ptr == NULL)
+	if(deps == NULL)
 	  return plugin;	
 	else
 	 {
-	 ret = plugin_next_unrun_dependencie(sched, deps_ptr, 1);
+	 ret = plugin_next_unrun_dependencie(sched, deps, 1);
 	 if(ret == NULL)
 		return plugin;
 	 else 
@@ -536,6 +537,7 @@ struct scheduler_plugin * plugin_next_unrun_dependencie(plugins_scheduler_t sche
     }
    }
   }
+  else fprintf(stderr, "%s could not be found\n", dependencies[i]);
  }
   
   if(flag == 0)
@@ -549,44 +551,36 @@ struct scheduler_plugin * plugin_next_unrun_dependencie(plugins_scheduler_t sche
 /*
  * Enables a plugin and its dependencies
  */
-static void enable_plugin_and_dependencies(plugins_scheduler_t shed, struct arglist * plugin, char * name, int silent)
+static void enable_plugin_and_dependencies(plugins_scheduler_t shed, struct arglist * plugin, char * name)
 {
- struct hash ** deps_ptr;
+ char ** deps;
  int i;
- int status;
  
- if ( plugin == NULL ) return;
+ deps = hash_get_deps(shed->hash, name);
 
- deps_ptr = hash_get_deps_ptr(shed->hash, name);
-
- status = plug_get_launch(plugin);
- if ( status == LAUNCH_DISABLED )
- {
-  if ( silent == 0 )
-   plug_set_launch(plugin, LAUNCH_RUN);
-  else
-   plug_set_launch(plugin, LAUNCH_SILENT);
- }
+ plug_set_launch(plugin, 1);
  
- if(deps_ptr != NULL)
+ if(deps != NULL)
  {
-   for(i=0;deps_ptr[i] != NULL;i++)
+   for(i=0;deps[i] != NULL;i++)
     {
      struct scheduler_plugin * p;
-     p = deps_ptr[i]->plugin;
-     if ( p != NULL && p->arglist != NULL ) enable_plugin_and_dependencies(shed, p->arglist->value, p->arglist->name, silent);
+     p = hash_get(shed->hash, deps[i]);
+     if( p != NULL )
+       enable_plugin_and_dependencies(shed, p->arglist->value, p->arglist->name);
+     else
+       log_write("'%s' depends on '%s' which could not be found\n", name, deps[i]);
     }
  }
 }
 
 /*---------------------------------------------------------------------------*/
 
-plugins_scheduler_t plugins_scheduler_init(struct arglist * plugins, int autoload, int silent_dependencies)
+plugins_scheduler_t plugins_scheduler_init(struct arglist * plugins, int autoload)
 {
  plugins_scheduler_t ret = emalloc(sizeof(*ret));
  struct arglist * arg;
  int i;
- struct hash * l;
  
  
  
@@ -633,22 +627,13 @@ plugins_scheduler_t plugins_scheduler_init(struct arglist * plugins, int autoloa
   }
  
  
- for ( i = 0 ; i < HASH_MAX ; i ++ )
- {
-  l = &ret->hash[i];
-  while ( l != NULL ){
-	 hash_fill_deps(ret->hash, l);
-	 l = l->next;
-	}
- }
- 
  if(autoload != 0)
  {
  arg = plugins;
  while(arg->next != NULL)
   {
-   if(plug_get_launch(arg->value) != LAUNCH_DISABLED)
-   	enable_plugin_and_dependencies(ret, arg->value, arg->name, silent_dependencies);
+   if(plug_get_launch(arg->value) != 0)
+   	enable_plugin_and_dependencies(ret, arg->value, arg->name);
    arg = arg->next;
   }
  }
@@ -660,9 +645,7 @@ plugins_scheduler_t plugins_scheduler_init(struct arglist * plugins, int autoloa
   struct list * l = ret->list[i];
   while (l != NULL )
   {
-   if(plug_get_launch(l->plugin->arglist->value) == LAUNCH_DISABLED && 
-      plug_get_category(l->plugin->arglist->value) != ACT_INIT &&
-      plug_get_category(l->plugin->arglist->value) != ACT_SETTINGS )
+   if(plug_get_launch(l->plugin->arglist->value) == 0)
    {
     struct list * old = l->next;
 
@@ -704,7 +687,7 @@ struct scheduler_plugin * plugins_scheduler_next(plugins_scheduler_t h)
  l = h->list[category];
  
  /*
-  * Scanners (and DoS) must not be run in parallel
+  * Scanners (and DoS) must not be run in parrallel
   */
 
  if((category == ACT_SCANNER) ||
@@ -727,11 +710,11 @@ struct scheduler_plugin * plugins_scheduler_next(plugins_scheduler_t h)
   {
    case PLUGIN_STATUS_UNRUN:
     {
-    struct hash ** deps_ptr = l->plugin->parent_hash->dependencies_ptr;
+    char ** deps = hash_get_deps(h->hash, l->plugin->arglist->name);
     
-    if(deps_ptr != NULL)
+    if(deps != NULL)
     {
-     struct scheduler_plugin * p = plugin_next_unrun_dependencie(h, deps_ptr, 0);
+     struct scheduler_plugin * p = plugin_next_unrun_dependencie(h, deps, 0);
      
      switch((int)p)
      {
@@ -804,8 +787,7 @@ struct scheduler_plugin * plugins_scheduler_next(plugins_scheduler_t h)
   
   /* Could not find anything */
   if((category == ACT_SCANNER ||
-     category == ACT_INIT || 
-     category == ACT_SETTINGS) && flag != 0)
+     category == ACT_INIT) && flag != 0)
      {
       pluginlaunch_wait_for_free_process();
       flag = 0;
@@ -842,6 +824,3 @@ void plugins_scheduler_free(plugins_scheduler_t sched)
  	list_destroy(sched->list[i]);	
  efree(&sched);
 }
-
-
-
