@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2006 Tenable Network Security, Inc.
+ * Copyright (C) 1998 - 2004 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -74,10 +74,10 @@ int preferences_new(char * name)
  fprintf(fd, "be_nice = no\n\n");
 
 
- fprintf(fd, "# Log file : \n");
+ fprintf(fd, "# Log file (or 'syslog') : \n");
  fprintf(fd, "logfile = %s\n\n", NESSUSD_MESSAGES);
- fprintf(fd, "# Shall we log every details of the attack ? (disk intensive)\n");
- fprintf(fd, "log_whole_attack = no\n\n");
+ fprintf(fd, "# Shall we log every details of the attack ?\n");
+ fprintf(fd, "log_whole_attack = yes\n\n");
  fprintf(fd, "# Log the name of the plugins that are loaded by the server ?\n");
  fprintf(fd, "log_plugins_name_at_load = no\n\n");
  fprintf(fd, "# Dump file for debugging output, use `-' for stdout\n");
@@ -92,10 +92,10 @@ int preferences_new(char * name)
  fprintf(fd, "# 'default' means that Nessus will scan ports found in its\n");
  fprintf(fd, "# services file.\n");
  fprintf(fd, "port_range = default\n\n");
- fprintf(fd, "# Optimize the test (recommended) : \n");
+ fprintf(fd, "# Optimize the test (recommanded) : \n");
  fprintf(fd, "optimize_test = yes\n\n");
  fprintf(fd, "# Language of the plugins :\n");
- fprintf(fd, "language = %s\n\n", NESSUSD_LANGUAGE);
+ fprintf(fd, "language = english\n\n");
 
  fprintf(fd, "\n\n# Optimization : \n");
  fprintf(fd, "# Read timeout for the sockets of the tests : \n");
@@ -109,8 +109,6 @@ int preferences_new(char * name)
  fprintf(fd, "safe_checks = yes\n");
  fprintf(fd, "\n\n# Automatically activate the plugins that are depended on\n");
  fprintf(fd, "auto_enable_dependencies = yes\n");
- fprintf(fd, "\n\n# Do not echo data from plugins which have been automatically enabled\n");
- fprintf(fd, "silent_dependencies = yes\n");
  fprintf(fd, "\n\n# Designate hosts by MAC address, not IP address (useful for DHCP networks)\n");
  fprintf(fd, "use_mac_addr = no\n");
  
@@ -204,15 +202,12 @@ int preferences_process(filename,prefs)
 	   
 	   buffer[sizeof(buffer) - 1] = '\0';
 	   len = strlen(buffer);
-	   if ( len == 0 ) continue;
 	   
 	   if(buffer[len-1]=='\n')
 	    {
 	     buffer[len-1]=0;
 	     len --;
 	    }
-
-	    if ( len <= 0 ) continue;
 	   
 	    if(buffer[0]=='#')continue;
 	    opt = buffer;
@@ -220,29 +215,26 @@ int preferences_process(filename,prefs)
 	    if( t == NULL )continue;
 	    else {
 	      t[0]=0;
-	      t++;
-	      while(t[0]==' ')t++;
+	      t+=sizeof(char);
+	      while(t[0]==' ')t+=sizeof(char);
 	      len = strlen(opt);
-	      while(len > 0 && opt[len-1]==' ')
+	      while(opt[len-1]==' ')
 	      {
 	       opt[len-1]= '\0';
 	       len --;
 	      }
-	      if ( len <= 0 ) continue;
 	      
 	      len = strlen(t);
-	      while(len > 0 && t[len-1]==' ')
+	      while(t[len-1]==' ')
 	      {
 	       t[len-1]= '\0';
 	       len --;
 	      }
-
-	      if ( len <= 0 ) continue;
-	      len = strlen(t);
+	      
 	      value = emalloc(len + 1);
 	      strncpy(value, t, len);
 	      arg_add_value(prefs, opt, ARG_STRING, strlen(value), value);
-#if DEBUGMORE
+#ifdef DEBUGMORE
 	      printf("%s = %s\n", opt, value);
 #endif
 	    }
@@ -902,32 +894,6 @@ preferences_detached_scan_email(preferences)
 }
 
 
-int
-preferences_silent_dependencies(preferences)
- struct arglist * preferences;
-{
- static int yes = -1;
- char * pref;
- 
- if(!preferences)
-  {
-   yes = -1;
-   return -1;
-  }
-  
-  
- if(yes >= 0)
-  return yes;
-  
-  
- pref = arg_get_value(preferences, "silent_dependencies");
- if(pref && !strcmp(pref, "yes"))
-   yes = 1;
- else
-   yes = 0;
-
- return yes;
-}
 
 
 #ifdef NESSUS_ON_SSL
@@ -969,5 +935,4 @@ preferences_reset_cache()
  preferences_delay_between_scans(NULL);
  preferences_detached_scan(NULL);
  preferences_detached_scan_email(NULL);
- preferences_silent_dependencies(NULL);
 }
