@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2006 Tenable Network Security, Inc.
+ * Copyright (C) 1998 - 2004 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -179,28 +179,19 @@ rules_init(rules, preferences)
  fclose(f);
 }
 
+
 struct nessus_rules *
-rules_dup_aux(s, r)
-  struct nessus_rules * s, *r;
+rules_dup(struct nessus_rules *source)
 {
-  printf("rules_dup called - does not work\n");
-  if(!s->next)return r;
-  else
+  struct nessus_rules *target = NULL;
+
+  if(source)
   {
-    r->ip.s_addr = s->ip.s_addr;
-    r->mask = s->mask;
-    r->rule = s->rule;
-    r->not = s->not;
-    r->def  = s->def;
-    r->next = emalloc(sizeof(*r));
-    return rules_dup_aux(s->next,r->next);
+    target = memcpy(emalloc(sizeof(struct nessus_rules)),
+		    source, sizeof(struct nessus_rules));
+    target->next = rules_dup(source->next);
   }
-}
-struct nessus_rules *
-rules_dup(struct nessus_rules *s)
-{
-  struct nessus_rules * r = emalloc(sizeof(*r));
-  return rules_dup_aux(s, r);
+  return target;
 }
 
 
