@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2006 Tenable Network Security, Inc.
+ * Copyright (C) 1998 - 2004 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -210,7 +210,7 @@ get_active_plugins_number(plugins)
   if(plugins != NULL)
    while(plugins->next != NULL)
    {
-    if(plug_get_launch(plugins->value) != LAUNCH_DISABLED )num++;
+    if(plug_get_launch(plugins->value))num++;
     plugins = plugins->next;
    }
    
@@ -364,8 +364,6 @@ temp_file_name()
  	if(close(fd) < 0)
 	 perror("close ");
 	}
- sprintf(ret, "%s/tmp", NESSUSD_STATEDIR);
- mkdir(ret, 0700);
  sprintf(ret, "%s/tmp/tmp.%d-%d", NESSUSD_STATEDIR, getpid(), rand()%1024);
  fd = open(ret, O_RDONLY);
  } 
@@ -495,14 +493,3 @@ int set_linger(soc, linger)
  l.l_linger = linger;
  return setsockopt(soc, SOL_SOCKET, SO_LINGER, (void*)&l, sizeof(l));
 }
-
-
-void wait_for_children1()
-{
- int e, n = 0;
- do {
- errno = 0;
- e = waitpid(-1, NULL, WNOHANG);
- n++;
- } while ( (e > 0 || errno == EINTR) && n < 20 );
-}
